@@ -5,10 +5,9 @@
 #' \itemize{
 #'   \item \code{\link{docx}} Create a Microsoft Word document object
 #'   \item \code{\link{pptx}} Create a Microsoft PowerPoint document object
-#'   \item \code{\link{bsdoc}} Create an HTML document object (deprecated)
 #' }
 #'
-#' The following functions can be used whatever the output format is (docx, pptx, bsdoc).
+#' The following functions can be used whatever the output format is (docx, pptx).
 #'
 #' \itemize{
 #'   \item \code{\link{addTitle}} Add a title
@@ -48,7 +47,7 @@
 #'
 #' @note
 #'
-#' Examples are in a \code{dontrun} section as they are using font that may be not
+#' Examples are in a \code{donttest} section as they are using font that may be not
 #' available on the host machine. Default font is Helvetica, it can be modified
 #' with option \code{ReporteRs-default-font}. To run an example with 'Arial'
 #' default font, run first
@@ -57,7 +56,6 @@
 #'
 #' @examples
 #' options("ReporteRs-fontsize"=10, "ReporteRs-default-font"="Helvetica")
-#' @example examples/options.listdefinitions.R
 #' @name ReporteRs-package
 #' @aliases ReporteRs
 #' @title ReporteRs: a package to create document from R
@@ -66,38 +64,3 @@
 NULL
 
 
-#' @title docx bookmarks
-#'
-#' @description \code{docx} can generate Word documents using bookmarks
-#' as placeholders to insert contents. Read MS documentation about bookmark here:
-#'
-#' http://office.microsoft.com/en-us/word-help/add-or-delete-bookmarks-HP001226532.aspx#BM1
-#'
-#' Functions \code{\link{addFlexTable}}, \code{\link{addPlot}}
-#' , \code{\link{addParagraph}} and \code{\link{addImage}} can send respective
-#' outputs into these bookmarks.
-#'
-#' These functions have an optional argument named \code{bookmark}.
-#'
-#' When used with \code{\link{addPlot}}, \code{\link{addParagraph}}
-#' and \code{\link{addImage}}, content (plots, paragraphs or images) will replace
-#' the whole paragraph containing the bookmark.
-#'
-#' When used with \code{\link{addFlexTable}}
-#' content (table) will be inserted after the paragraph containing the bookmark.
-#'
-#' To be used with a \code{docx} object, bookmark must be placed into
-#' a single paragraph, if placed along 1 or more paragraphs
-#' side effects could occur and insertion of a content could fail.
-#'
-#' You can insert the bookmark at the beginning of the paragraph (see the file
-#' bookmark_example.docx in the templates directory of the package for an example)
-#' or on a portion of a text in a paragraph.
-#'
-#' @examples
-#'
-#' @example examples/bookmark.R
-#' @seealso \code{\link{docx}}
-#' @name docx-bookmark
-#' @aliases bookmark
-NULL
