@@ -231,7 +231,7 @@ public class docx4R {
 		numberingDefinition.stackToExistingList(existingNb);
 		if( Debug.debug_list ) System.err.println("stacked " );
 
-		Numbering newNumber = (Numbering) (numberingDefinition.get_flextable_docx());
+		Numbering newNumber = (Numbering) (numberingDefinition.get_docx_elt());
 
 		ndp = new NumberingDefinitionsPart();
 		ndp.setJaxbElement( newNumber );
@@ -377,7 +377,7 @@ public class docx4R {
 		toc.setDOCXMLPackage(basedoc);
 		toc.setUID(eltIndex+1);
 
-		basedoc.getMainDocumentPart().getContent().add(toc.get_flextable_docx());
+		basedoc.getMainDocumentPart().getContent().add(toc.get_docx_elt());
 
 		eltIndex = (int) toc.next_id();
 		eventManage();
@@ -389,7 +389,7 @@ public class docx4R {
 		dt.setDOCXReference(this);
 
 		Tbl tbl;
-		tbl = dt.get_flextable_docx();
+		tbl = dt.get_docx_elt();
 		basedoc.getMainDocumentPart().addObject(tbl);
 		eltIndex = (int) dt.next_id();
 		eventManage();
@@ -397,7 +397,7 @@ public class docx4R {
 	
 	public void add_xml_flextable( String str, String textalign) throws Exception {
 		XMLreader obj = new XMLreader(str);
-		Tbl tbl = obj.get_flextable_docx();
+		Tbl tbl = obj.get_docx_elt();
 		Jc alignment = new Jc();
 		
 		if( textalign.equals("left")) alignment.setVal(JcEnumeration.LEFT);
@@ -417,7 +417,7 @@ public class docx4R {
 		if( bo.exists() ){
 			P p = bo.getP();
 			XMLreader obj = new XMLreader(str);
-			Tbl tbl = obj.get_flextable_docx();
+			Tbl tbl = obj.get_docx_elt();
 			Jc alignment = new Jc();
 			
 			if( textalign.equals("left")) alignment.setVal(JcEnumeration.LEFT);
@@ -444,7 +444,7 @@ public class docx4R {
 			dt.setParProperties(pp);
 			dt.setUID(eltIndex+1);
 			dt.setDOCXReference(this);
-			Tbl tbl = dt.get_flextable_docx();
+			Tbl tbl = dt.get_docx_elt();
 		    int i = ((ContentAccessor)p.getParent()).getContent().indexOf(p);
 		    ((ContentAccessor)p.getParent()).getContent().add(i+1, tbl);
 			eltIndex = (int) dt.next_id();
@@ -458,7 +458,7 @@ public class docx4R {
 		rscript.setDOCXMLPackage(basedoc);
 		rscript.setParProperties(pp);
 		rscript.setUID(eltIndex + 1 );
-		basedoc.getMainDocumentPart().getContent().addAll(rscript.get_flextable_docx());
+		basedoc.getMainDocumentPart().getContent().addAll(rscript.get_docx_elt());
 		eltIndex = (int) rscript.next_id();
 		eventManage();
 	}
@@ -477,7 +477,7 @@ public class docx4R {
 			P p = bo.getP();
 		    int i = ((ContentAccessor)p.getParent()).getContent().indexOf(p);
 		    ((ContentAccessor)p.getParent()).getContent().remove(i);
-		    Vector<P> pars = rscript.get_flextable_docx();
+		    Vector<P> pars = rscript.get_docx_elt();
 		    for( int pid = 0 ; pid < rscript.size() ; pid++ ){
 		    	((ContentAccessor)p.getParent()).getContent().add(i+pid, pars.get(pid));
 		    }
@@ -492,7 +492,7 @@ public class docx4R {
 		script.setDOCXMLPackage(basedoc);
 		script.setParProperties(pp);
 		script.setUID(eltIndex + 1 );
-		basedoc.getMainDocumentPart().getContent().addAll(script.get_flextable_docx());
+		basedoc.getMainDocumentPart().getContent().addAll(script.get_docx_elt());
 		eltIndex = (int) script.next_id();
 		eventManage();
 	}
@@ -511,7 +511,7 @@ public class docx4R {
 			P p = bo.getP();
 		    int i = ((ContentAccessor)p.getParent()).getContent().indexOf(p);
 		    ((ContentAccessor)p.getParent()).getContent().remove(i);
-		    Vector<P> pars = script.get_flextable_docx();
+		    Vector<P> pars = script.get_docx_elt();
 		    for( int pid = 0 ; pid < script.size() ; pid++ ){
 		    	((ContentAccessor)p.getParent()).getContent().add(i+pid, pars.get(pid));
 		    }
@@ -571,7 +571,7 @@ public class docx4R {
 		par.setUID(eltIndex + 1 );
 		
 		if( par.size() > 0 ){
-			Vector<P> parset = par.get_flextable_docx();
+			Vector<P> parset = par.get_docx_elt();
 			for( int i = 0 ; i < parset.size() ; i++ )
 				basedoc.getMainDocumentPart().addObject(parset.get(i));
 		}
@@ -584,14 +584,13 @@ public class docx4R {
 		BookmarkObject bo = DocExplorer.getBookmarkObject(bookmark, basedoc);
 		if( bo.exists() ){
 			int bmk_index = bo.getBookmarkID().intValue();
-
 			par.setUID(eltIndex + 1 );
 			par.set_docx_bookmark(bookmark, bo.getBookmarkID());
 
 			P p = bo.getP();
 		    int i = ((ContentAccessor)p.getParent()).getContent().indexOf(p);
 		    ((ContentAccessor)p.getParent()).getContent().remove(i);
-			Vector<P> parset = par.get_flextable_docx();
+			Vector<P> parset = par.get_docx_elt();
 	    	((ContentAccessor)p.getParent()).getContent().addAll(i, parset );
 			eltIndex = eltIndex + par.size();
 
