@@ -83,7 +83,7 @@ public class Image extends DocComponent implements HTML4R, PPTX4R{
 		return unique_id+2;
 	}
 	
-	public Object get_pptx_elt() throws Exception {
+	public Object get_flextable_pptx() throws Exception {
 				
         BinaryPartAbstractImage imagePart = BinaryPartAbstractImage.createImagePart(pptx_mlp, slidePart, image_bytes);
         Relationship rel = slidePart.addTargetPart(imagePart);
@@ -146,8 +146,7 @@ public class Image extends DocComponent implements HTML4R, PPTX4R{
 		P paragraph = new P(); 
 		paragraph.setPPr(getPPr());
 		
-		addBookmark(paragraph);
-
+		paragraph.getContent().add(new R()); 
 		R run = new R(); 
 		paragraph.getContent().add(run); 
 
