@@ -613,7 +613,7 @@ public class FlexTable extends DocComponent implements HTML4R, PPTX4R, DOCX4R {
 		}
 		return true;
 	}
-	public Tbl get_flextable_docx() throws Exception{
+	public Tbl get_docx_elt() throws Exception{
 		
 		if( !validateDOCXComponent() ) throw new Exception("class FlexTable: elements need to be set...");
 		sendMetaDocxReference();
